==> wildfly-ee-dist-22.0.1.Final-src.zip: wildfly-22.0.1.Final-src/clustering/marshalling/spi/src/main/java/org/wildfly/clustering/marshalling/spi/util/UUIDExternalizer.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2012, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.wildfly.clustering.marshalling.spi.util;

import java.io.IOException;
import java.io.ObjectInput;
import java.io.ObjectOutput;
import java.util.OptionalInt;
import java.util.UUID;

import org.wildfly.clustering.marshalling.Externalizer;

/**
 * {@link Externalizer} for {@link UUID} instances.
 * @author Paul Ferraro
 */
public class UUIDExternalizer implements Externalizer<UUID> {

    @Override
    public void writeObject(ObjectOutput output, UUID uuid) throws IOException {
        output.writeLong(uuid.getMostSignificantBits());
        output.writeLong(uuid.getLeastSignificantBits());
    }

    @Override
    public UUID readObject(ObjectInput input) throws IOException {
        return new UUID(input.readLong(), input.readLong());
    }

    @Override
    public Class<UUID> getTargetClass() {
        return UUID.class;
    }

    @Override
    public OptionalInt size(UUID object) {
        return OptionalInt.of(Long.BYTES + Long.BYTES);
    }
}

==> wildfly-ee-dist-27.0.1.Final-src.zip: wildfly-27.0.1.Final-src/clustering/marshalling/spi/src/main/java/org/wildfly/clustering/marshalling/spi/util/UUIDExternalizer.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2012, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.wildfly.clustering.marshalling.spi.util;

import java.util.OptionalInt;
import java.util.UUID;

import org.wildfly.clustering.marshalling.Externalizer;
import org.wildfly.clustering.marshalling.spi.SerializerExternalizer;

/**
 * {@link Externalizer} for {@link UUID} instances.
 * @author Paul Ferraro
 */
public class UUIDExternalizer extends SerializerExternalizer<UUID> {

    public UUIDExternalizer() {
        super(UUID.class, UUIDSerializer.INSTANCE);
    }

    @Override
    public OptionalInt size(UUID object) {
        return OptionalInt.of(Long.BYTES + Long.BYTES);
    }
}
